@@ -1,5 +1,5 @@
 # Claudio Perez
-__version__ = "0.1.6"
+__version__ = "0.1.11"
 
 from pathlib import Path
 
@@ -29,13 +29,14 @@ def read(read_file, input_format=None, **kwds):
     """
     Generic ground motion reader
     """
+    input_format = input_format or kwds.pop("format",None)
     if input_format is not None:
         typ = input_format
     else:
         try:
-            typ = DEFAULT_TYPES[Path(read_file).suffix]
+            typ = DEFAULT_TYPES[Path(read_file).suffix.lower()]
         except KeyError:
-            raise ValueError("Unable to deduce input format")
+            raise ValueError("Unable to deduce input format.\n")
     return FILE_TYPES[typ]["read"](read_file, **kwds)
 
 
