@@ -26,19 +26,9 @@ def build_parser():
     )
 
     parser.add_argument("read_file", metavar="FILE", nargs="?", default="-")
-    parser.add_argument(
-            "-o", 
-            dest="write_file", 
-            default="-",
-            help="Specify an output file."
-    )
-    parser.add_argument(
-            "--human",
-            default=False,
-            action="store_true",
-            help="Use human friendly field names."
-    )
     #parser.add_argument("-c", dest="command", action="append")
+    #parser.add_argument("validate", action="store_true", default=False
+    #)
     parser.add_argument(
         "-f",
         dest="input_format",
@@ -46,6 +36,19 @@ def build_parser():
         help="Specify input file format",
         choices=list(quakeio.FILE_TYPES.keys()),
     )
+    parser.add_argument(
+        "-t", "--to",
+        dest="write_format",
+        metavar="FORMAT",
+        help="Specify output file format",
+        default="json",
+    )
+    parser.add_argument(
+            "--human",
+            default=False,
+            action="store_true",
+            help="Use human friendly field names."
+    )
     parser.add_argument(
         "-x",
         "--exclude",
@@ -56,11 +59,16 @@ def build_parser():
         default=[]
     )
     parser.add_argument(
-        "-t", "--to",
-        dest="write_format",
-        metavar="FORMAT",
-        help="Specify output file format",
-        default="json",
+            "-m",
+            dest="match_patterns",
+            action="append",
+            default=[]
+    )
+    parser.add_argument(
+            "-o",
+            dest="write_file",
+            default="-",
+            help="Specify an output file."
     )
     parser.add_argument(
         "-r",
@@ -84,8 +92,30 @@ def build_parser():
     return parser
 
 
-def cli(*args, write_file="-", human=False, version=False, command=None, **kwds):
-    motion = quakeio.read(**kwds)
+def cli(*args, write_file="-", human=False, validate=False, version=False, command=None, **kwds):
+    read_file = kwds.pop("read_file")
+    if "?" in read_file:
+        from urllib.parse import urlparse
+        url = urlparse(read_file)
+        read_file = url.path
+        query = url.query
+    else:
+        query = None
+
+    motion = quakeio.read(read_file, **kwds)
+
+    if kwds["match_patterns"]:
+        kvs = {}
+        for pat in kwds["match_patterns"]:
+            key, val = pat.split("=")
+            try:
+                key, typ = key.split(":")
+            except:
+                typ = "l"
+            kvs.update({key: val})
+            motion = motion.match(typ, **kvs)
+    if validate:
+        run_validation(motion)
     if human:
         motion = quakeio.core.write_pretty(motion)
     if "angle" in kwds and kwds["angle"]:
@@ -94,15 +124,24 @@ def cli(*args, write_file="-", human=False, version=False, command=None, **kwds)
     quakeio.write(write_file, motion, **kwds)
     print("\n")
 
+def run_validation(collection):
+    for motion in collection.motions:
+        for component in motion.components:
+            for series in component.series:
+                pass
+    pass
 
 def list_args(*args):
     args = build_parser().parse_args()
     return cli(**vars(args))
 
-
-def main():
-    args = build_parser().parse_args()
-    cli(**vars(args))
+def main(args=None):
+    args = build_parser().parse_args(args)
+    try:
+        cli(**vars(args))
+    except Exception as e:
+        print(args)
+        raise e
 
 
 if __name__ == "__main__":
