@@ -10,8 +10,14 @@ RE_TIME_STEP = re.compile(r"DT=\s+(.*)SEC")
 
 def read_nga(read_file, *args, **kwds):
     with open_quake(read_file, "r") as f:
-        header = [next(f) for _ in range(4)]
+        match = RE_TIME_STEP.search(next(f))
+        header = [""]
+        while RE_TIME_STEP.search(header[-1]) is None:
+            header.append(next(f))
+            
+        #header = [next(f) for _ in range(4)]
     dt = float(RE_TIME_STEP.search(header[-1]).group(1).strip())
+    #dt = float(match.group(1).strip())
     series_type = header[-2][:5].lower()
     accel = np.genfromtxt(read_file, skip_header=4, skip_footer=1).flatten()
     return QuakeSeries(
