@@ -13,9 +13,11 @@ import matplotlib.pyplot as plt
 try:
     style_file = Path(__file__).parents[0]/"brace2.mplstyle"
     plt.style.use([style_file])
-    plt.plot([0.0, 1.0], [0.0, 0.1], label=r"$\sigma")
-except Exception as e:
-    print(e)
+    import tempfile
+    with tempfile.NamedTemporaryFile() as tf:
+        plt.plot([0.0, 1.0], [0.0, 0.1], label=r"$\sigma")
+        plt.savefig(tf.name)
+except RuntimeError as e:
     import matplotlib
     matplotlib.rcParams.update({
         "text.usetex": False,
@@ -47,7 +49,7 @@ def _plot_func(plot):
             self.fig = self.ax.figure
         else:
             self.fig, self.ax = plt.subplots()
-            
+
         if "title" in kwds:
             self.ax.set_title(kwds.pop("title"))
 
@@ -72,7 +74,7 @@ class Spectrum:
             from scipy.interpolate import interp1d as interp
         if damping is None:
             damping = ("damping" in self.kwds and self.kwds.pop("damping")) or 0.0
-        
+
         if accel is None:
             accel = self._accel
         if isinstance(accel, QuakeComponent):
@@ -85,8 +87,12 @@ class Spectrum:
         if isinstance(damping, float):
             damping = [damping]
 
+        if per is None:
+            per = self.kwds.get("per",None)
         if per is None:
             per = np.arange(0.02, 1.0, 0.01)
+        elif isinstance(per,tuple):
+            per = np.linspace(*per)
 
         return _accel_spectrum(
             accel=accel,
@@ -97,7 +103,7 @@ class Spectrum:
             damping=damping,
             interp=interp
         )
-    
+
 
     @_plot_func
     def plot(self, **kwds):
@@ -106,6 +112,8 @@ class Spectrum:
         if len(tsa) > 2:
             for sa in tsa[1:]:
                 self.ax.plot(tsa[0], sa)
+        else:
+            self.ax.plot(tsa[0],tsa[1])
         self.ax.set_xlabel(f"Period, (sec.)")
         chn = self._accel["channel"]
         self.ax.set_title(f"Response spectrum (Chn. {chn})")
@@ -116,6 +124,11 @@ class TransferFunction(Spectrum):
         self._pairs = pairs
         self.kwds = kwds
 
+    def tf(self):
+        self.tf = tsa = transfer_function(self._pairs, **self.kwds)
+        return tsa
+
+
     @_plot_func
     def plot(self, **kwds):
         self.tf = tsa = transfer_function(self._pairs, **self.kwds)
@@ -138,54 +151,54 @@ def spectrum(*args, **kwds):
     return _accel_spectrum(*args, **kwds)
 
 def _accel_spectrum(accel,dt,damping,per,gamma=1/2,beta=1/4,interp=None):
-    numper=len(per)
+    numper = len(per)
     m = 1.0
-    numdata=len(accel)
-    t=np.arange(0,(numdata)*dt,dt)
-    
+    numdata = len(accel)
+    t = np.arange(0,(numdata)*dt,dt)
+
     u0,v0 = 0.0, 0.0
-    SA = np.zeros((1+len(damping),numper))
+    SA = np.zeros((1+len(damping), numper))
     SA[0,:] = per[:]
 
     for di,dmp in enumerate(damping):
 
         for i in range(numper):
             if dt/per[i]>0.02:
-                dtp=per[i]*0.02;
-                dtpx=np.arange(0,max(t),dtp)
-                dtpx=dtpx
-                accfrni=interp(t, accel)(dtpx);
-                accfrn=accfrni[1:len(accfrni)-1];
-                numdatan=len(accfrn);
-                p=-m*accfrn;
+                dtp = per[i]*0.02
+                dtpx = np.arange(0,max(t),dtp)
+                dtpx = dtpx
+                accfrni = interp(t, accel)(dtpx)
+                accfrn = accfrni[1:len(accfrni)-1]
+                numdatan = len(accfrn)
+                p  =  -m*accfrn
             else:
-                dtp=dt;
-                accfrn = accel;
-                p = -m*accfrn;
-                numdatan=numdata;
+                dtp = dt
+                accfrn = accel
+                p = -m*accfrn
+                numdatan = numdata
 
             u = np.zeros((numdatan))
             v = np.zeros((numdatan))
             a = np.zeros((numdatan))
 
-            k = 4*pi**2*m/per[i]**2;
-            c = 2*dmp*np.sqrt(k/m);
+            k = 4*pi**2*m/per[i]**2
+            c = 2*dmp*np.sqrt(k/m)
             kstar = k + gamma*c/(beta*dtp) + m/(beta*dtp**2.0)
             acons = m/(beta*dtp) + gamma*c/beta
             bcons = m/(2*beta) + dtp*(gamma/(2*beta)-1)*c
-            u[0] = u0;
-            v[0] = v0;
-            a[0] = (p[0]-c*v[0]-k*u[0])/m;
+            u[0] = u0
+            v[0] = v0
+            a[0] = (p[0]-c*v[0]-k*u[0])/m
             for j in range(1,numdatan):
-                deltap=p[j]-p[j-1];
-                deltaph=deltap+acons*v[j-1]+bcons*a[j-1];
-                deltau=deltaph/kstar;
-                deltav=gamma*deltau/(beta*dtp)-gamma*v[j-1]/beta+dtp*(1-gamma/(2*beta))*a[j-1];
-                deltaa=deltau/(beta*dtp**2)-v[j-1]/(beta*dtp)-a[j-1]/(2*beta);
-                u[j]=u[j-1] + deltau;
-                v[j]=v[j-1] + deltav;
-                a[j]=a[j-1] + deltaa;
-            atot=a+accfrn;
-            SA[1+di,i]=abs(max(atot, key=abs));
+                deltap = p[j]-p[j-1]
+                deltaph = deltap+acons*v[j-1]+bcons*a[j-1]
+                deltau = deltaph/kstar
+                deltav = gamma*deltau/(beta*dtp) - gamma*v[j-1]/beta+dtp*(1-gamma/(2*beta))*a[j-1]
+                deltaa = deltau/(beta*dtp**2)-v[j-1]/(beta*dtp)-a[j-1]/(2*beta)
+                u[j] = u[j-1] + deltau
+                v[j] = v[j-1] + deltav
+                a[j] = a[j-1] + deltaa
+            atot = a + accfrn
+            SA[1+di,i] = abs(max(atot, key=abs))
     return SA
 
